bayespy.inference.vmp.nodes.node.Moments.compute_fixed_moments
==============================================================

.. currentmodule:: bayespy.inference.vmp.nodes.node

.. automethod:: Moments.compute_fixed_moments